@@ -24,21 +24,23 @@
 #ifndef CALLBACKS_H
 #define CALLBACKS_H
 
-#define PAUSE_WITH_HW_KEY "/apps/osso/games_startup/pause_with_hw_key"
+#include <SDL/SDL.h>
 
-int exit_callback(int errcode/*, AppData *app_data*/);
-int quit_callback(int errcode/*, AppData *app_data*/);
+
+/* #define PAUSE_WITH_HW_KEY "/apps/osso/games_startup/pause_with_hw_key" */
+
+int exit_callback(int errcode);
+int quit_callback(int errcode);
 int flush_callback(int errcode);
 
+/* We don't need timeouts?
 Uint32 app_escape_timeout(Uint32 interval, void *param);
 void app_remove_timeout(void);
-
-void app_set_pause_hw_key(int keyval);
-
-/*
-  Call this function in time consuming loops, because we want to run
-  osso (dbus) for hw-events.
 */
+
+/* 
+ * Call this function in time consuming loops, because we want to run osso
+ * (dbus) for hw-events. */
 void gmainloop(void);
 
 #endif /* CALLBACKS_H */
