@@ -618,7 +618,7 @@ G_Run()
 {
 
     int leave = 0;
-    int restart = 0;
+    int restart = (gm.c_lvl->tm <= 0);
     int ms;
     SDL_Event ev;
     int restore_pos;
@@ -1286,6 +1286,18 @@ G_Ps()
             case SDL_KEYUP:
                 if (e.key.keysym.sym == SDLK_p)
                     leave = 1;
+            case SDL_KEYDOWN:
+                if ((e.key.keysym.sym == SDLK_ESCAPE)
+                    || (e.key.keysym.sym == SDLK_F4)
+                    || (e.key.keysym.sym == SDLK_F5)
+                    || (e.key.keysym.sym == SDLK_F6))
+                {
+                    exit_gm = 1;
+                    leave = 1;
+                    exiting_needed = 1;
+                    exit_callback(0);
+                    return;
+                }
                 break;
             case SDL_MOUSEMOTION:
                 mx = e.motion.x;
